@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 #
 # The MIT License (MIT)
-# 
+#
 # Copyright (c) 2018 Philippe Faist
-# 
+#
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
 # to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 # copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be included in
 # all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 # IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -31,7 +31,7 @@ searching.
 The main class is :py:class:`LatexNodes2Text`.  For a quick start, try::
 
     from pylatexenc.latex2text import LatexNodes2Text
-    
+
     latex = "... LaTeX code ..."
     text = LatexNodes2Text().latex_to_text(latex)
 
@@ -84,11 +84,11 @@ class MacroTextSpec(object):
          - If `simplify_repl` is a string, this string is used as the text
            representation of this macro node.
 
-           The string may contain a '%s' replacement placeholder, in which the
-           macro arguments will be substituted in the given order.
-           Alternatively, the string may contain '%(<n>)s' (where `<n>` is an
-           integer) to refer to the n-th argument (starting at '%(1)s').  You
-           cannot mix the two %-formatting styles.
+           The string may contain a single '%s' replacement placeholder which
+           will be replaced by the concatenated textual representation of all
+           macro arguments.  Alternatively, the string may contain '%(<n>)s'
+           (where `<n>` is an integer) to refer to the n-th argument (starting
+           at '%(1)s').  You cannot mix the two %-formatting styles.
 
          - If `simplify_repl` is a callable, it should accept the corresponding
            :py:class:`pylatexenc.latexwalker.LatexMacroNode` as an argument.
@@ -100,7 +100,7 @@ class MacroTextSpec(object):
            provided to that argument.
 
     .. py:attribute:: discard
-    
+
        If set to `True`, then the macro call is discarded, i.e., it is converted
        to an empty string.
 
@@ -154,7 +154,7 @@ class EnvironmentTextSpec(object):
            environment is provided to that argument.
 
     .. py:attribute:: discard
-    
+
        If set to `True`, then the full environment is discarded, i.e., it is
        converted to an empty string.
 
@@ -176,7 +176,7 @@ class SpecialsTextSpec(object):
     A specification of how to obtain a textual representation of latex specials.
 
     .. py:attribute:: specials_chars
-    
+
        The sequence of special LaTeX characters
 
     .. py:attribute:: simplify_repl
@@ -187,8 +187,10 @@ class SpecialsTextSpec(object):
          - If `simplify_repl` is a string, this string is used as the text
            representation of this specials node.
 
-           The string may contain a '%s' replacement placeholder, in which the
-           macro arguments will be substituted in the given order.
+           The string may contain a single '%s' replacement placeholder which
+           will be replaced by the concatenated textual representation of all
+           macro arguments.
+
            Alternatively, the string may contain '%(<n>)s' (where `<n>` is an
            integer) to refer to the n-th argument (starting at '%(1)s').  You
            cannot mix the two %-formatting styles.
@@ -249,8 +251,8 @@ def MacroDef(macname, simplify_repl=None, discard=None):
 # functions should be considered internal API and should not be relied upon for
 # the moment in production code.  I intend to change some things in how common
 # rendering procedures (for equations, for non-textual content that probably
-# requires a placeholder, etc.) by extending the latex context database object
-# directly.
+# requires a placeholder, etc.) by some other means such as by extending the
+# latex context database object directly.
 #
 
 def fmt_equation_environment(envnode, l2tobj):
@@ -303,7 +305,7 @@ def placeholder_node_formatter(placeholdertext, block=True):
     """
     return  lambda n, l2tobj, pht=placeholdertext: \
         _do_fmt_placeholder_node(pht, l2tobj, block=block)
-    
+
 def _do_fmt_placeholder_node(placeholdertext, l2tobj, block=True):
     # spaces added so that database indexing doesn't index the word "array" or
     # "pmatrix"
@@ -459,12 +461,12 @@ def get_default_latex_context_db():
     :py:meth:`pylatexenc.macrospec.LatexContextDb.filter_context()`.
 
     .. versionadded:: 2.0
- 
+
        The :py:class:`pylatexenc.macrospec.LatexContextDb` class as well as this
        method, were all introduced in `pylatexenc 2.0`.
     """
     db = macrospec.LatexContextDb()
-    
+
     from ._defaultspecs import specs
 
     for cat, catspecs in specs:
@@ -472,9 +474,9 @@ def get_default_latex_context_db():
                                 macros=catspecs['macros'],
                                 environments=catspecs['environments'],
                                 specials=catspecs['specials'])
-    
+
     return db
-    
+
 
 
 
@@ -553,18 +555,15 @@ _strict_latex_spaces_predef = {
         'between-macro-and-chars': True,
         'between-latex-constructs': True,
         'after-comment': False,
-        'in-equations': False,
+        'in-equations': 'based-on-source',
     },
     'except-in-equations': {
         'between-macro-and-chars': True,
         'between-latex-constructs': True,
         'after-comment': True,
-        'in-equations': False,
+        'in-equations': 'based-on-source',
     },
 }
-# compatibility with pylatexenc 1.x, but it is no longer the default!!
-_strict_latex_spaces_predef['default'] = _strict_latex_spaces_predef['based-on-source']
-
 
 
 def _parse_strict_latex_spaces_dict(strict_latex_spaces):
@@ -576,6 +575,11 @@ def _parse_strict_latex_spaces_dict(strict_latex_spaces):
     }
     if strict_latex_spaces is None:
         return d
+    elif strict_latex_spaces is False:
+        # "False" == the actual default for non-strict latex spaces == "macros"
+        return _strict_latex_spaces_predef['macros']
+    elif strict_latex_spaces is True:
+        return dict([(k, True) for k in d.keys()])
     elif isinstance(strict_latex_spaces, dict):
         d.update(strict_latex_spaces)
         return d
@@ -589,19 +593,20 @@ def _parse_strict_latex_spaces_dict(strict_latex_spaces):
                              .format(strict_latex_spaces))
 
         if strict_latex_spaces == 'default': # deprecated -- report this
+            # compatibility with pylatexenc 1.x, but it is no longer the default!!
             _util.pylatexenc_deprecated_2(
-                "The value 'default' for `strict_latex_spaces=` in LatexNodes2Text() is deprecated. "
-                "The actual default changed to 'macros', and for backwards compatibility the "
-                "obsolete value 'default' still refers to the earlier default which is now called "
-                "'based-on-source'.",
+                "The value 'default' for `strict_latex_spaces=` in LatexNodes2Text() "
+                "is deprecated. The actual default changed to 'macros', and for "
+                "backwards compatibility the obsolete value 'default' still refers to "
+                "the earlier default which is now called 'based-on-source'.",
                 stacklevel=4
             )
+            strict_latex_spaces = 'based-on-source'
 
         return _strict_latex_spaces_predef[strict_latex_spaces]
     else:
-        for k in d.keys():
-            d[k] = bool(strict_latex_spaces)
-        return d
+        raise ValueError("Invalid value for strict_latex_spaces: {!r}"
+                         .format(strict_latex_spaces))
 
 
 class LatexNodes2Text(object):
@@ -648,10 +653,10 @@ class LatexNodes2Text(object):
 
     - `strict_latex_spaces=True|False`: If set to `True`, then we follow closely
       LaTeX's handling of whitespace.  For instance, whitespace following a bare
-      macro (i.e. w/o any delimiting characters like '{') is consumed/removed.
-      If set to `False` (the default), then some liberties are taken with
-      respect to whitespace [hopefully making the result slightly more
-      aesthetic, but this behavior is mostly there for historical reasons].
+      macro (i.e. without any delimiting characters like '{') is
+      consumed/removed.  If set to `False` (the default), then some liberties
+      are taken with respect to whitespace [hopefully making the result slightly
+      more aesthetic, but this behavior is mostly there for historical reasons].
 
       You may also use one of the presets
       `strict_latex_spaces='based-on-source'|'macros'|'except-in-equations'`,
@@ -662,8 +667,13 @@ class LatexNodes2Text(object):
           that are present in the source file in several situations where LaTeX
           would remove them, including after macros.  This is meant to be
           hopefully slightly more aesthetic.  However, this option might
-          inadvertently break up words: For instance, "Sk\l odowska" would be
-          replaced by "Skł odowska".
+          inadvertently break up words: For instance::
+
+              Sk\l odowska
+
+          would be replaced by::
+
+             Skł odowska
 
         - The value 'macros' is the same as specifying
           `strict_latex_spaces=False`, and it is the default.  It will make
@@ -680,7 +690,8 @@ class LatexNodes2Text(object):
       either `True` or `False`, dictating whitespace behavior in specific cases
       (`True` indicates strict latex behavior).  The value for 'in-equations'
       may even be another dictionary with the same keys to override values in
-      equations.
+      equations.  A value of `False` for 'in-equation' has the same meaning as
+      'macros'.
 
       .. versionchanged:: 2.0
 
@@ -692,6 +703,13 @@ class LatexNodes2Text(object):
          The value 'default' is also accepted, but it is no longer the default!
          It is an alias for 'based-on-source'
 
+      .. versionchanged:: 2.6
+
+         In `pylatexenc` versions 2.0–2.5, contrary to the documentation, the
+         default value of `strict_latex_spaces` was actually still
+         'based-on-source'.  This bug was fixed in version 2.6, so that now, the
+         default setting is actually 'macros'.
+
     - `keep_braced_groups=True|False`: If set to `True`, then braces delimiting
       a TeX group ``{Like this}`` will be kept in the output, with the contents
       of the group converted to text as usual.  (By default this is `False`)
@@ -712,7 +730,7 @@ class LatexNodes2Text(object):
 
        Added the `math_mode=` flag to replace the poorly designed
        `keep_inline_math=` flag;
-    
+
        Added the `fill_text=` flag.
 
     Additionally, the following arguments are accepted for backwards compatibility:
@@ -722,7 +740,7 @@ class LatexNodes2Text(object):
       `False`, this is the same as `math_mode='text'`.
 
       .. deprecated:: 2.0
-    
+
          The `keep_inline_math=` option is deprecated because it had a weird
          behavior and was poorly implemented, especially given that a similarly
          named option in :py:class:`LatexWalker` had a different effect.  See
@@ -763,7 +781,7 @@ class LatexNodes2Text(object):
                     "obsolete since pylatexenc 2.  They will still work, but please consider "
                     "using instead the more versatile option `latex_context=...`."
                 )
-                
+
                 macro_dict = flags.pop('macro_dict', [])
                 env_dict = flags.pop('env_dict', [])
 
@@ -823,8 +841,9 @@ class LatexNodes2Text(object):
 
         if flags:
             # any flags left which we haven't recognized
-            logger.warning("LatexNodes2Text(): Unknown flag(s) encountered: %r", list(flags.keys()))
-        
+            logger.warning("LatexNodes2Text(): Unknown flag(s) encountered: %r",
+                           list(flags.keys()))
+
 
     def set_tex_input_directory(self, tex_input_directory, latex_walker_init_args=None,
                                 strict_input=True):
@@ -884,12 +903,13 @@ class LatexNodes2Text(object):
 
         fnfull = os.path.realpath(os.path.join(self.tex_input_directory, fn))
         if self.strict_input:
-            # make sure that the input file is strictly within dirfull, and didn't escape with
-            # '../..' tricks or via symlinks.
+            # make sure that the input file is strictly within dirfull, and
+            # didn't escape with '../..' tricks or via symlinks.
             dirfull = os.path.realpath(self.tex_input_directory)
             if not fnfull.startswith(dirfull):
                 logger.warning(
-                    "Can't access path '%s' leading outside of mandated directory [strict input mode]",
+                    "Can't access path '%s' leading outside of mandated directory "
+                    "[strict input mode]",
                     fn
                 )
                 return ''
@@ -901,7 +921,7 @@ class LatexNodes2Text(object):
         if not os.path.isfile(fnfull):
             logger.warning(u"Error, file doesn't exist: '%s'", fn)
             return ''
-        
+
         logger.debug("Reading input file %r", fnfull)
 
         try:
@@ -916,9 +936,10 @@ class LatexNodes2Text(object):
         #
         # recurse into files upon '\input{}'
         #
-        
+
         if len(n.nodeargs) != 1:
-            logger.warning(u"Expected exactly one argument for '\\input' ! Got = %r", n.nodeargs)
+            logger.warning(u"Expected exactly one argument for '\\input' ! Got = %r",
+                           n.nodeargs)
 
         inputtex = self.read_input_file(self.nodelist_to_text([n.nodeargs[0]]).strip())
 
@@ -944,7 +965,9 @@ class LatexNodes2Text(object):
         The `parse_flags` are keyword arguments to provide to the
         :py:class:`pylatexenc.latexwalker.LatexWalker` constructor.
         """
-        return self.nodelist_to_text(latexwalker.LatexWalker(latex, **parse_flags).get_latex_nodes()[0])
+        return self.nodelist_to_text(
+            latexwalker.LatexWalker(latex, **parse_flags).get_latex_nodes()[0]
+        )
 
 
     def nodelist_to_text(self, nodelist):
@@ -954,15 +977,17 @@ class LatexNodes2Text(object):
         :py:meth:`pylatexenc.latexwalker.LatexWalker.get_latex_nodes()`.
 
         This function basically applies `node_to_text()` to each node and
-        concatenates the results into one string.  (But not quite actually,
-        since we take some care as to where we add whitespace according to the
-        class options.)
+        concatenates the results into one string.  (This is not quite actually
+        the case, since we take some care as to where we add whitespace
+        according to the class options.)
         """
 
         s = ''
         prev_node = None
         for node in nodelist:
-            if self._is_bare_macro_node(prev_node) and node.isNodeType(latexwalker.LatexCharsNode):
+            if self._is_bare_macro_node(prev_node) and \
+               node.isNodeType(latexwalker.LatexCharsNode):
+
                 if not self.strict_latex_spaces['between-macro-and-chars']:
                     # after a macro with absolutely no arguments, include
                     # post_space in output by default if there are other chars
@@ -998,19 +1023,19 @@ class LatexNodes2Text(object):
 
         # ### It doesn't look like we use prev_node_hint at all.  Eliminate at
         # ### some point?
-        
+
         if node.isNodeType(latexwalker.LatexCharsNode):
             return self.chars_node_to_text(node, textcol=textcol)
-        
+
         if node.isNodeType(latexwalker.LatexCommentNode):
             return self.comment_node_to_text(node)
-        
+
         if node.isNodeType(latexwalker.LatexGroupNode):
             return self.group_node_to_text(node)
-        
+
         if node.isNodeType(latexwalker.LatexMacroNode):
             return self.macro_node_to_text(node)
-        
+
         if node.isNodeType(latexwalker.LatexEnvironmentNode):
             return self.environment_node_to_text(node)
 
@@ -1039,7 +1064,8 @@ class LatexNodes2Text(object):
         content = node.chars
         if self.fill_text: # None or column width
             content = self.do_fill_text(content, textcol=textcol)
-        if not self.strict_latex_spaces['between-latex-constructs'] and len(content.strip()) == 0:
+        if not self.strict_latex_spaces['between-latex-constructs'] \
+           and len(content.strip()) == 0:
             return ""
         return content
 
@@ -1059,14 +1085,16 @@ class LatexNodes2Text(object):
                     nl = ''
                 return '%' + node.comment + nl
             else:
-                # default spaces, i.e., keep what spaces were already there after the comment
+                # default spaces, i.e., keep what spaces were already there
+                # after the comment
                 return '%' + node.comment + node.comment_post_space
         else:
             if self.strict_latex_spaces['after-comment']:
                 return ""
             else:
-                # default spaces, i.e., keep what spaces were already there after the comment
-                # This can be useful to preserve e.g. indentation of the next line
+                # default spaces, i.e., keep what spaces were already there
+                # after the comment.  This can be useful to preserve
+                # e.g. indentation of the next line
                 return node.comment_post_space
 
 
@@ -1209,6 +1237,7 @@ class LatexNodes2Text(object):
         trail_par = '\n\n' if ('\n\n' in trail_ws) else ''
         #trail_nl = '\n' if (not trail_par and '\n' in trail_ws) else ''
         text = text.strip()
+
         def fill_chunk(x, textcol):
             #head_ws = ' ' if textcol>0 and x[0:1].isspace() else ''
             #trail_ws = ' ' if x[-1:].isspace() else ''
@@ -1220,12 +1249,21 @@ class LatexNodes2Text(object):
                 return head_ws + \
                     textwrap.fill(x, self.fill_text, initial_indent='X'*textcol)[textcol:] + \
                     trail_ws
-        return head_par + (' ' if textcol>0 and head_ws and not head_par else '') + "\n\n".join(
-            chunk
-            for chunk in (fill_chunk(x, textcol if j==0 else 0)
-                          for j, x in enumerate(re.compile(r'\n{2,}').split(text)))
-            if chunk.strip()
-        ) + (' ' if trail_ws and not trail_par else '') + trail_par
+
+        rawchunks = re.compile(r'\n{2,}').split(text)
+
+        chunks = [
+            thechunk
+            for (j, thechunk) in (
+                    ( j, fill_chunk(x, textcol if j==0 else 0) )
+                    for j, x in enumerate(rawchunks)
+            )
+            if thechunk.strip()
+        ]
+
+        return head_par + (' ' if textcol>0 and head_ws and not head_par else '') + \
+            "\n\n".join(chunks) + \
+            (' ' if trail_ws and not trail_par else '') + trail_par
 
     def apply_simplify_repl(self, node, simplify_repl, what):
         r"""
@@ -1256,7 +1294,12 @@ class LatexNodes2Text(object):
                 return r
             return '' # don't return None
 
-        if '%' in simplify_repl:
+        if '%' in simplify_repl and len(simplify_repl) != 1:
+            # if simplify_repl contains a '%' sign then we will look for %-based
+            # formatting placeholder(s), except if simplify_repl is the string
+            # '%' itself (checked above with "len(simplify_repl)!=1") in which
+            # case it is a literal replacement percent symbol.
+
             nodeargs = []
             if node.nodeargd and node.nodeargd.argnlist:
                 nodeargs = node.nodeargd.argnlist
@@ -1299,12 +1342,12 @@ class LatexNodes2Text(object):
             # additional newlines because neighboring text gets trimmed
             block = '\n'+block+'\n'
         return block
-    
+
 
     def _is_bare_macro_node(self, node):
         return (node is not None and
-                node.isNodeType(latexwalker.LatexMacroNode) and 
-                node.nodeoptarg is None and 
+                node.isNodeType(latexwalker.LatexMacroNode) and
+                node.nodeoptarg is None and
                 len(node.nodeargs) == 0)
 
     def _groupnodecontents_to_text(self, groupnode):
@@ -1331,20 +1374,20 @@ class LatexNodes2Text(object):
 
         If you used custom `text_replacements=` in `pylatexenc 1.x` then you
         will have to change::
-  
+
           # pylatexenc 1.x with text_replacements
           text_replacements = ...
           l2t = LatexNodes2Text(..., text_replacements=text_replacements)
           text = l2t.nodelist_to_text(...)
-  
+
         to::
-  
+
           # pylatexenc 2 text_replacements compatibility code
           text_replacements = ...
           l2t = LatexNodes2Text(...)
           temp = l2t.nodelist_to_text(...)
           text = l2t.apply_text_replacements(temp, text_replacements)
-  
+
         as a quick fix.  It is recommended however to treat text replacements
         instead as "latex specials".  (Otherwise the brutal text replacements
         might act on text generated from macros and environments and give
@@ -1359,7 +1402,7 @@ class LatexNodes2Text(object):
            not recommended for new code.  You should use "latex specials"
            instead for characters that have special LaTeX meaning.
         """
-        
+
         # perform suitable replacements
         for pattern, replacement in text_replacements:
             if hasattr(pattern, 'sub'):
